@@ -137,7 +137,7 @@ def max_drawdown(X):
             mdd = dd
     return mdd
 
-@numba.jit('i8[:](i8[:])')
+@numba.jit('f8[:](f8[:])')
 def pivots_to_modes(pivots):
     """
     Given an array of pivots (computed by zigzag), return the interpolated 
